@@ -3,6 +3,7 @@ from pathlib import Path
 from cli.generator import generate_project , run_server
 from rich.logging import RichHandler
 import logging
+from importlib import resources
 
 logging.basicConfig(
     level="INFO",
@@ -23,17 +24,23 @@ def create(
     skip_install: bool = typer.Option(False, "--skip-install", help="Skip installing dependencies"),
 ):
     frameworks = {
-        "fastapi": "cli/templates/fastapi",
-        "flask": "cli/templates/flask",
-        "django": "cli/templates/django"
-        }
+        "fastapi": "fastapi",
+        "flask": "flask",
+        "django": "django"
+    }
 
     if framework.lower() not in frameworks:
         logger.error("Invalid framework. Choose from: fastapi, flask, django.")
         raise typer.Exit(code=1)
 
-    template_path = frameworks[framework.lower()]
-    generated_project_dir = generate_project(template_path, name, output_dir=output, skip_install=skip_install)
+    framework_dir_name = frameworks[framework.lower()]
+    template_path = Path(resources.files("cli") / "templates" / framework_dir_name)
+    generated_project_dir = generate_project(
+        template_path, 
+        name, 
+        output_dir=output, 
+        skip_install=skip_install
+    )
     run_server(generated_project_path=generated_project_dir)
 
 
